package com.yingji.quartz;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.yingji.entity.Fire;
import com.yingji.service.FireService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 119数据保存定时任务
 *
 * @author wu
 * @since 2024/05/06 10:18
 */
@Configuration
public class FireQuartz {

    public static final Logger log = LoggerFactory.getLogger(FireQuartz.class);

    @Resource
    private FireService fireService;

    /**
     * 保存所有数据
     */
    @Async
    @Scheduled(cron = "0 */5 * * * ? ")
    public void savaData() {
        log.info("119接口开始" + LocalDateTime.now());
        // 获取token
        String token = fireService.getToken();
        if (StrUtil.isNotEmpty(token)) {
            // 根据id查询数据保存
            List<Fire> list = fireService.findDataList(token);
            // 110算法接口
            if (CollectionUtil.isNotEmpty(list)) {
                fireService.saveAll(list);
            }
            log.info("119接口结束" + LocalDateTime.now());
        } else {
            log.error("============119算法接口获取token失败119接口结束=============");
        }
    }

}
